InstancePatchStateFilter class

Defines a filter used in DescribeInstancePatchStatesForPatchGroup used to scope down the information returned by the API.

Constructors

InstancePatchStateFilter({required String key, required InstancePatchStateOperatorType type, required List<String> values})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
The key for the filter. Supported values are FailedCount, InstalledCount, InstalledOtherCount, MissingCount and NotApplicableCount.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InstancePatchStateOperatorType
The type of comparison that should be performed for the value: Equal, NotEqual, LessThan or GreaterThan.
final
values → List<String>
The value for the filter, must be an integer greater than or equal to 0.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited